package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmReportIllegalDay;

/**
 * 违章日统计Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-28
 */
public interface PdmReportIllegalDayMapper
{
    /**
     * 查询违章日统计
     *
     * @param id 违章日统计主键
     * @return 违章日统计
     */
    public PdmReportIllegalDay selectPdmReportIllegalDayById(Long id);

    /**
     * 查询违章日统计列表
     *
     * @param pdmReportIllegalDay 违章日统计
     * @return 违章日统计集合
     */
    public List<PdmReportIllegalDay> selectPdmReportIllegalDayList(PdmReportIllegalDay pdmReportIllegalDay);

    /**
     * 新增违章日统计
     *
     * @param pdmReportIllegalDay 违章日统计
     * @return 结果
     */
    public int insertPdmReportIllegalDay(PdmReportIllegalDay pdmReportIllegalDay);

    /**
     * 修改违章日统计
     *
     * @param pdmReportIllegalDay 违章日统计
     * @return 结果
     */
    public int updatePdmReportIllegalDay(PdmReportIllegalDay pdmReportIllegalDay);

    /**
     * 删除违章日统计
     *
     * @param id 违章日统计主键
     * @return 结果
     */
    public int deletePdmReportIllegalDayById(Long id);

    /**
     * 批量删除违章日统计
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmReportIllegalDayByIds(Long[] ids);
}
